data(simDat3)
balm <- ~ X1 * X2
g <- Y ~ Z
ps <- Z~X1*X2
## A print and summary methods exist for this class
fit1 <- matching(form=g, balm=balm, data=simDat3, type="ACE", bcForm=balm)
fit1
fit2 <- LLmatching(form=g, psForm=ps, data=simDat3, type="ACE")
fit2
fit3 <- ipw(form=g, psForm=ps, data=simDat3, type="ACE", normalized=TRUE)
fit3
## A print and summary methods exist for this class
summary(fit1)
Run the code above in your browser using DataLab